
.. blogpost::
    :title: version_information
    :keywords: version_information
    :date: 2016-06-18
    :categories: module

    Small extension to display information about a module in a notebook.

    ::

        %load_ext version_information

    See :ref:`versioninformationrst`.
